@@ -13,10 +13,11 @@ import (
 	"strings"
 
 	"github.com/mitchellh/mapstructure"
-	costmanagementmetricscfgv1beta1 "github.com/project-costmanagement/costmanagement-metrics-operator/api/v1beta1"
-	"github.com/project-costmanagement/costmanagement-metrics-operator/dirconfig"
 	promv1 "github.com/prometheus/client_golang/api/prometheus/v1"
 	"github.com/prometheus/common/model"
+
+	costmanagementmetricscfgv1beta1 "github.com/project-costmanagement/costmanagement-metrics-operator/api/v1beta1"
+	"github.com/project-costmanagement/costmanagement-metrics-operator/dirconfig"
 )
 
 var (
@@ -79,10 +80,23 @@ func getResourceID(input string) string {
 	return splitString[len(splitString)-1]
 }
 
+func generateKey(metric model.Metric, keys []model.LabelName) string {
+	if len(keys) == 1 {
+		return string(metric[keys[0]])
+	}
+	result := []string{}
+	for _, key := range keys {
+		result = append(result, string(metric[key]))
+	}
+	sort.Strings(result)
+
+	return strings.Join(result, ",")
+}
+
 func (r *mappedResults) iterateMatrix(matrix model.Matrix, q query) {
 	results := *r
 	for _, stream := range matrix {
-		obj := string(stream.Metric[q.RowKey])
+		obj := generateKey(stream.Metric, q.RowKey)
 		if results[obj] == nil {
 			results[obj] = mappedValues{}
 		}
