@@ -14,12 +14,13 @@ import (
 	"testing"
 	"time"
 
+	promv1 "github.com/prometheus/client_golang/api/prometheus/v1"
+	"github.com/prometheus/common/model"
+
 	costmanagementmetricscfgv1beta1 "github.com/project-costmanagement/costmanagement-metrics-operator/api/v1beta1"
 	"github.com/project-costmanagement/costmanagement-metrics-operator/dirconfig"
 	"github.com/project-costmanagement/costmanagement-metrics-operator/strset"
 	"github.com/project-costmanagement/costmanagement-metrics-operator/testutils"
-	promv1 "github.com/prometheus/client_golang/api/prometheus/v1"
-	"github.com/prometheus/common/model"
 )
 
 var testLogger = testutils.TestLogger{}
@@ -128,19 +129,9 @@ func TestGenerateReports(t *testing.T) {
 	queryList := []*querys{nodeQueries, namespaceQueries, podQueries, volQueries}
 	for _, q := range queryList {
 		for _, query := range *q {
-			if query.Chunked {
-				for _, v := range [12]string{"00", "05", "10", "15", "20", "25", "30", "35", "40", "45", "50", "55"} {
-					res := &model.Matrix{}
-					filename := fmt.Sprintf("%s-%s", query.Name, v)
-					Load(filepath.Join("test_files", "test_data", filename), res, t)
-					key := fmt.Sprintf("%s-%s", query.QueryString, v)
-					mapResults[key] = &mockPromResult{value: *res}
-				}
-			} else {
-				res := &model.Matrix{}
-				Load(filepath.Join("test_files", "test_data", query.Name), res, t)
-				mapResults[query.QueryString] = &mockPromResult{value: *res}
-			}
+			res := &model.Matrix{}
+			Load(filepath.Join("test_files", "test_data", query.Name), res, t)
+			mapResults[query.QueryString] = &mockPromResult{value: *res}
 		}
 	}
 
@@ -194,19 +185,9 @@ func TestGenerateReportsQueryErrors(t *testing.T) {
 	queryList := []*querys{nodeQueries, podQueries, volQueries}
 	for _, q := range queryList {
 		for _, query := range *q {
-			if query.Chunked {
-				for _, v := range [12]string{"00", "05", "10", "15", "20", "25", "30", "35", "40", "45", "50", "55"} {
-					res := &model.Matrix{}
-					filename := fmt.Sprintf("%s-%s", query.Name, v)
-					Load(filepath.Join("test_files", "test_data", filename), res, t)
-					key := fmt.Sprintf("%s-%s", query.QueryString, v)
-					mapResults[key] = &mockPromResult{value: *res}
-				}
-			} else {
-				res := &model.Matrix{}
-				Load(filepath.Join("test_files", "test_data", query.Name), res, t)
-				mapResults[query.QueryString] = &mockPromResult{value: *res}
-			}
+			res := &model.Matrix{}
+			Load(filepath.Join("test_files", "test_data", query.Name), res, t)
+			mapResults[query.QueryString] = &mockPromResult{value: *res}
 		}
 	}
 	namespaceError := "namespace error"
@@ -436,7 +417,7 @@ func TestIterateMatrix(t *testing.T) {
 					Factor:          maxFactor,
 					TransformedName: "node-allocatable-cpu-core-seconds",
 				},
-				RowKey: "node",
+				RowKey: []model.LabelName{"node"},
 			},
 			matrix: model.Matrix{
 				{
@@ -469,7 +450,7 @@ func TestIterateMatrix(t *testing.T) {
 				Name:           "node-labels",
 				QueryString:    "kube_node_labels",
 				MetricKeyRegex: regexFields{"node_labels": "label_*"},
-				RowKey:         "node",
+				RowKey:         []model.LabelName{"node"},
 			},
 			matrix: model.Matrix{
 				{
@@ -512,7 +493,7 @@ func TestIterateMatrix(t *testing.T) {
 					Factor:          maxFactor,
 					TransformedName: "node-capacity-cpu-core-seconds",
 				},
-				RowKey: "node",
+				RowKey: []model.LabelName{"node"},
 			},
 			matrix: model.Matrix{
 				{
